# inept

An "**in**teractive **e**ditable o**pt**ions" library for handling complex option hierarchies
from multiple sources (script, CLI, config files, ...).

## Installation 

Install inept with pip

```bash 
  pip install inept
```

## Documentation

The documentation is available online : https://inept.rtfd.io/

Take a look at the [quick start](https://inept.readthedocs.io/en/latest/quick-start.html) for a demo or at the [roadmap](https://inept.readthedocs.io/en/latest/roadmap.html) to see where the project is heading.


## Contributing

You are welcome to help the project, see [how](https://inept.readthedocs.io/en/latest/contributing.html).


## Used By

This project is used by the following softwares:

- https://github.com/BRGM/ComPASS

## License

[GPLv3](https://www.gnu.org/licenses/gpl-3.0.en.html)

